import { newsDetailsStore } from "./store";
import "./NewsDetailsPage.scss";
import HeaderText from "@/Shared/UI/HeaderText/HeaderText";
import message_icon from "./icons/message-icon.svg";
import calendar_icon from "./icons/calendar-icon.svg";
import Image from "next/image";
import NewsReviewsSection from "@/Widgets/NewsReviewsSection/NewsReviewsSection";

const NewsDetailsPage = async ({
  params,
}: {
  params: { id: string };
}) => {
  const data = await newsDetailsStore.getNewsDetails(params.id);

  console.log(data);

  const months: Record<string, string> = {
    "01": "Январь",
    "02": "Февраль",
    "03": "Март",
    "04": "Апрель",
    "05": "Май",
    "06": "Июнь",
    "07": "Июль",
    "08": "Август",
    "09": "Сентябрь",
    "10": "Октябрь",
    "11": "Ноябрь",
    "12": "Декабрь",
  };

  const year = data?.created_at.slice(0, 4);
  const month = data?.created_at.slice(5, 7);
  const day = data?.created_at.slice(8, 10);

  return (
    <div className="news-details-page">
      <HeaderText>{data?.title}</HeaderText>
      <div className="news-details-page__wrapper">
        <div className="news-details-page__image">
          <img
            src={data?.image}
            alt="News Image"
            className="news-details-page__image_main"
          />
          <div className="news-details-page__date-and-reviews">
            <span>
              <Image src={calendar_icon} alt="Calendar Icon" />
              {month && months[month]} {day}, {year}
            </span>
            <span>
              <Image src={message_icon} alt="Message Icon" />
              Комментарии: {data?.count_reviews}
            </span>
          </div>
        </div>

        <p className="news-details-page__description">
          {data?.description}
        </p>

        <NewsReviewsSection id={data?.id} list={data?.news_review} />
      </div>
    </div>
  );
};

export default NewsDetailsPage;
